@@ -4,6 +4,8 @@
 import os
 from time import sleep
 
+import yaml
+
 from ccvs_scanning_api_client.api.analysis_api import AnalysisApi
 from ccvs_scanning_api_client.api_client import ApiClient
 from ccvs_scanning_api_client.configuration import Configuration
@@ -13,9 +15,12 @@ from ccvs_scanning_api_client.models.analysis import Analysis
 config = Configuration(host=os.environ.get('CCVS_API'))
 
 
-def analysis(image_name):
+def analysis(image_name, whitelist_file):
     analysis_api = AnalysisApi(ApiClient(config))
-    analysis_obj = analysis_api.analysis_create(Analysis(image=image_name))
+    whitelist = read_whitelist_file(whitelist_file)
+    analysis_obj = analysis_api.analysis_create(
+        Analysis(image=image_name, whitelist=whitelist)
+    )
     x = 0
     print('Analysis: ', analysis_obj.id)  # noqa
     while True:
@@ -31,12 +36,14 @@ def analysis(image_name):
     return analysis_result
 
 
-def resume(analysis_result):
+def summary(analysis_result):
     link = f'{config.host}container-scanning/analysis/{analysis_result.id}'
     resume = {
         'image': analysis_result.image,
         'link': link,
         'result': analysis_result.result,
+        'errors': analysis_result.errors,
+        'whitelist': analysis_result.whitelist,
         'total_vulns': {
             'high_vulns': 0,
             'medium_vulns': 0,
@@ -47,7 +54,7 @@ def resume(analysis_result):
         }
     }
 
-    vulns = analysis_result.vulnerabilities
+    vulns = analysis_result.ccvs_results
     if vulns:
         for vuln in vulns.values():
             if vuln:
@@ -55,3 +62,16 @@ def resume(analysis_result):
                     resume['total_vulns'][level[0]] += len(level[1])
 
     return resume
+
+
+def read_whitelist_file(whitelist_file):
+
+    print('Reading whitelist file')  # noqa
+    with open(whitelist_file, 'r') as stream:
+        try:
+            data_loaded = yaml.safe_load(stream)
+        except yaml.YAMLError as exc:
+            print('Error reading whitelist file. Error: %s', exc)  # noqa
+            return {}
+        else:
+            return data_loaded
